@@ -45,8 +45,8 @@
     License=MIT/X Licnese
 
     \author  HigePon
-    \version $Revision: 1.39 $
-    \date   create:2002/07/21 update:$Date: 2004/11/03 12:52:15 $
+    \version $Revision: 1.39.2.2 $
+    \date   create:2002/07/21 update:$Date: 2005/01/16 13:41:58 $
 */
 
 #define GLOBAL_VALUE_DEFINED
@@ -78,7 +78,7 @@
 #define CC_VER  __GNUC__, __GNUC_MINOR__, __GNUC_PATCHLEVEL__
 #endif
 
-const char* version = "Mona version.0.2.0 $Date: 2004/11/03 12:52:15 $";
+const char* version = "Mona version.0.2.1 $Date: 2005/01/16 13:41:58 $";
 dword version_number  = 0x00000200;
 void  mainProcess();
 
@@ -127,7 +127,12 @@ void startKernel(void)
         g_console->clearScreen();
     }
 
-#if 0
+    g_console->printf("\n");
+    g_console->printf("              %s\n", version);
+    g_console->printf("              ["CC_NAME" @ %s]\n", CC_VER, OSTYPE);
+    g_console->printf("              Copyright (c) 2002-2004 higepon\n\n\n\n");
+
+#if 1
     int w = g_vesaDetail->xResolution;
     int bpp = g_vesaDetail->bitsPerPixel / 8;
     byte *vram = (byte*)g_vesaDetail->physBasePtr;
@@ -135,19 +140,38 @@ void startKernel(void)
     switch (bpp) {
         case 2:
             for (int y = 0; y < 105; y++) {
-                for (int x = 0; x < 110; x++) {
-                    byte *pixel = &vram[(x + y * w) * bpp];
-                    word rgb16 = (word)(((palette16[monaboot[y][x]] >> 8) & 0xF800) | 
-                        ((palette16[monaboot[y][x]] >> 5) & 0x07E0) | ((palette16[monaboot[y][x]] >> 3) & 0x001F));
+                for (int x = 0; x < 55; x++) {
+                    byte *pixel = NULL;
+                    word rgb16  = 0;
+                    // hi 4bit
+                    pixel = &vram[(x * 2 + y * w) * bpp];
+                    rgb16 = (word)(((palette16[(monaboot[y][x] >> 4) & 0xF] >> 8) & 0xF800) |
+                        ((palette16[(monaboot[y][x] >> 4) & 0xF] >> 5) & 0x07E0) |
+                        ((palette16[(monaboot[y][x] >> 4) & 0xF] >> 3) & 0x001F));
+                    *((word*)pixel) = rgb16;
+                    // low 4bit
+                    pixel = &vram[(x * 2 + 1 + y * w) * bpp];
+                    rgb16 = (word)(((palette16[monaboot[y][x] & 0xF] >> 8) & 0xF800) |
+                        ((palette16[monaboot[y][x] & 0xF] >> 5) & 0x07E0) |
+                        ((palette16[monaboot[y][x] & 0xF] >> 3) & 0x001F));
                     *((word*)pixel) = rgb16;
                 }
            }
             break;
         default:
             for (int y = 0; y < 105; y++) {
-                for (int x = 0; x < 110; x++) {
-                    byte *pixel = &vram[(x + y * w) * bpp];
-                    byte* p_color = (byte*)&palette16[monaboot[y][x]];
+                for (int x = 0; x < 55; x++) {
+                    byte *pixel   = NULL;
+                    byte *p_color = NULL;
+                    // hi 4bit
+                    pixel = &vram[(x * 2 + y * w) * bpp];
+                    p_color = (byte*)&palette16[(monaboot[y][x] >> 4) & 0xF];
+                    pixel[0] = p_color[0];
+                    pixel[1] = p_color[1];
+                    pixel[2] = p_color[2];
+                    // low 4bit
+                    pixel = &vram[(x * 2 + 1 + y * w) * bpp];
+                    p_color = (byte*)&palette16[monaboot[y][x] & 0xF];
                     pixel[0] = p_color[0];
                     pixel[1] = p_color[1];
                     pixel[2] = p_color[2];
@@ -159,10 +183,6 @@ void startKernel(void)
 
     g_log = new LogConsole();
 
-    //g_console->printf("\n\n\n\n\n\n\n"); // added by bayside
-    g_console->printf("%s ["CC_NAME" @ %s]\n", version, CC_VER, OSTYPE);
-    g_console->printf("Copyright (c) 2002-2004 higepon\n\n");
-
     pic_init();
     RTC::init();
     printOK("Setting PIC        ");
@@ -325,7 +345,7 @@ int execSysConf()
     if (!(g_fs->open("/MONA.CFG", 1)))
     {
         g_fdcdriver->motorAutoOff();
-	systemcall_mutex_unlock(g_mutexFloppy);
+    systemcall_mutex_unlock(g_mutexFloppy);
         return 1;
     }
 
@@ -339,7 +359,7 @@ int execSysConf()
     if (buf == NULL)
     {
         g_fdcdriver->motorAutoOff();
-	systemcall_mutex_unlock(g_mutexFloppy);
+    systemcall_mutex_unlock(g_mutexFloppy);
         return 2;
     }
 
@@ -348,7 +368,7 @@ int execSysConf()
     {
         free(buf);
         g_fdcdriver->motorAutoOff();
-	systemcall_mutex_unlock(g_mutexFloppy);
+    systemcall_mutex_unlock(g_mutexFloppy);
         return g_fs->getErrorNo();
     }
 
@@ -356,7 +376,7 @@ int execSysConf()
     if (!g_fs->close())
     {
         g_fdcdriver->motorAutoOff();
-	systemcall_mutex_unlock(g_mutexFloppy);
+    systemcall_mutex_unlock(g_mutexFloppy);
     }
 
     g_fdcdriver->motorAutoOff();
