@@ -143,28 +143,42 @@ void FontManager::loadFont(char *path)
 */
 Font **FontManager::decodeString(char *str, int *length)
 {
-	int i , j, n = 0, len = 0;
+	int i , j, n = 0, len = 0, slen = strlen(str);
 	unsigned char c1 = 0, c2 = 0, c3 = 0;
 
-	for (i = 0; i < (int)strlen(str); i++) {
-		// 文字列の終端
-		if (str[i] == 0) break;
+	for (i = 0; i < slen; i++) {
 		// 1 バイト目
-		c1 = (unsigned char)str[i];
+		if (str[i] == 0) {
+			break;
+		} else {
+			c1 = (unsigned char)str[i];
+		}
 		// 0aaa bbbb - > 0aaa bbbb (0x20-0x7F)
 		if (0x20 <= c1 && c1 <= 0x7F) {
 			n = c1;
 		// 110a aabb 10bb cccc -> 0000 0aaa bbbb cccc (0xC280-0xDFBF)
 		} else if (0xC2 <= c1 && c1 <= 0xDF) {
 			// 2 バイト目
-			c2 = (unsigned char)str[++i];
-			n = ((c1 & 0x1F) >> 6) | (c2 & 0x3F);
+			if (str[i] == 0) {
+				break;
+			} else {
+				c2 = (unsigned char)str[++i];
+			}
+			n = ((c1 & 0x1F) << 6) | (c2 & 0x3F);
 		// 1110 aaaa 10bb bbcc 10cc dddd -> aaaa bbbb cccc dddd (0xE0A080-0xEFBFBF)
 		} else if (0xE0 <= c1 && c1 <= 0xEF) {
 			// 2 バイト目
-			c2 = (unsigned char)str[++i];
+			if (str[i] == 0) {
+				break;
+			} else {
+				c2 = (unsigned char)str[++i];
+			}
 			// 3 バイト目
-			c3 = (unsigned char)str[++i];
+			if (str[i] == 0) {
+				break;
+			} else {
+				c3 = (unsigned char)str[++i];
+			}
 			n = ((c1 & 0xF) << 12) | ((c2 & 0x3F) << 6) | (c3 & 0x3F);
 		} else {
 			n = 0;
